Parser
------

- class :cpp:class:`bitwuzla::parser::Parser`
- :ref:`cpp/classes/parser:example`

----

:code:`namespace bitwuzla::parser {`

.. doxygenclass:: bitwuzla::parser::Parser
    :project: Bitwuzla_cpp
    :members:

:code:`}`

----

Example
^^^^^^^

The source code for this example can be found at `examples/c/parse.cpp <https://github.com/bitwuzla/bitwuzla/tree/main/examples/cpp/parse.cpp>`_.

.. literalinclude:: ../../../examples/cpp/parse.cpp
     :language: cpp
